@@ -7,6 +7,7 @@ import pandas as pd
 import numpy as np
 from bs4 import BeautifulSoup
 from scipy.stats import norm, mstats
+from urllib.parse import quote
 warnings.filterwarnings("ignore")
 
 
@@ -44,7 +45,7 @@ one_day = datetime.timedelta(days=1)
 
 # 请求头；
 headers = {
-    "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.87 Safari/537.36"
+    "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 11_2_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.81"
 }
 
 # 钉钉推送；
@@ -629,6 +630,8 @@ class Get_App_SamePubApp(Get_App_Appinfo, Qimai_Diy_Var):
                 self.app_total_genid = info['total']['brand']
                 self.app_class_genid = info['class']['brand']
                 return self.app_total_genid, self.app_class_genid
+            else:
+                return '', ''
 
     def samePubApp_sorce(self):
         """
@@ -1518,17 +1521,18 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
         Qimai_Diy_Var.__init__(self)
         self.snapshot = snapshot
 
-    def get_updateTime_list(self):
+    def get_updateTime_data(self):
         """
             * 获取榜单快照更新时间列表；
         """
         url = 'https://api.qimai.cn/rank/indexSnapshot?brand=%s&device=%s&country=%s&genre=%s&date=%s&page=1&is_rank_index=1' %(self.brand, self.device, self.country, self.genre_type, self.run_time)
         res = session.get(url, headers=headers)
-        self.rank_update_List = res.json()
+        self.rank_update_data = res.json()
+        return self.rank_update_data
 
     def get_freeRank_list(self, max_index=1000000):
         """
-            * 获取免费榜产品列表：
+            * 获取免费榜产品列表-所有页面：
             :param max_index: 获取产品数量
         """
         self.app_freeRank_list = []
@@ -1544,6 +1548,14 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_freeRank_list
 
+    def get_freeRank_onePage(self):
+        """
+            * 获取免费榜产品列表-第一页：
+        """
+        url = 'https://api.qimai.cn/rank/index?brand=free&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_paidRank_list(self, max_index=1000000):
         """
             * 获取付费榜产品列表：
@@ -1562,6 +1574,14 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_paidRank_list
 
+    def get_paidRank_onePage(self):
+        """
+            * 获取付费榜产品列表-第一页：
+        """
+        url = 'https://api.qimai.cn/rank/index?brand=paid&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_grossRank_list(self, max_index=1000000):
         """
             * 获取畅销榜产品列表：
@@ -1580,6 +1600,14 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_grossRank_list
 
+    def get_grossRank_onePage(self):
+        """
+            * 获取畅销榜产品列表-第一页：
+        """
+        url = 'https://api.qimai.cn/rank/index?brand=grossing&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 获取预估下载量及预估收入接口；
 class Get_AppDownRevenue_Data(Qimai_Diy_Var):
     """
